@@ -480,6 +480,14 @@ BOOL CSoundFile::SetWaveConfig(UINT nRate,UINT nBits,UINT nChannels,BOOL bMMX)
 	return TRUE;
 }
 
+BOOL CSoundFile::SetMixConfig(UINT nStereoSeparation, UINT nMaxMixChannels)
+//-------------------------------------------------------------------------
+{
+	m_nMaxMixChannels = nMaxMixChannels;
+	m_nStereoSeparation = nStereoSeparation;
+	return TRUE;
+}
+
 
 BOOL CSoundFile::SetResamplingMode(UINT nMode)
 //--------------------------------------------
